@@ -37,10 +37,7 @@ Returns the response as xml UTF8 bytes for output.
 
 sub asBytes{
     my ($self,  $resp ) = @_ ;
-    my $xmlString =  XMLout($resp , RootName => 'response' ) ;
-    # xmlString is a string, not bytes
-    # return bytes.
-    return Encode::encode_utf8($xmlString) ;
+    return XMLout($resp , RootName => 'response' ) ;
 }
 
 1;
